pub struct RedisOptions {
pub rate_limit: RedisRateLimitOptions,
pub secondary_storage: RedisSecondaryStorageOptions,
}Expand description
Shared connection options for rate limiting and secondary storage.
Fields
rate_limit: RedisRateLimitOptionssecondary_storage: RedisSecondaryStorageOptionsTrait Implementations
Sourceimpl Clone for RedisOptions
impl Clone for RedisOptions
Sourcefn clone(&self) -> RedisOptions
fn clone(&self) -> RedisOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RedisOptions
impl Debug for RedisOptions
Sourceimpl Default for RedisOptions
impl Default for RedisOptions
Sourcefn default() -> RedisOptions
fn default() -> RedisOptions
Returns the “default value” for a type. Read more
impl Eq for RedisOptions
Sourceimpl PartialEq for RedisOptions
impl PartialEq for RedisOptions
Sourcefn eq(&self, other: &RedisOptions) -> bool
fn eq(&self, other: &RedisOptions) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RedisOptions